#include <avr/io.h>
#include <avr/interrupt.h>
#include "lcd.h"
#include "ff.h"
#include "diskio.h"

void SDTimerInit(void) {
	OCR0 = F_CPU / 1024 / 100 - 1;
	TCCR0 = _BV(WGM01) | _BV(CS02) | _BV(CS00); //CTC, F_CPU/1024
	TIMSK = _BV(OCIE0); //output compare
}

int main(void) {
	lcdInit();
	lcdInitPrintf();
	SDTimerInit(); //timer do komunikacji z kart
	sei();
	FATFS fatFs;
	PORTB |= _BV(PORTB3); // CD pull-up
	while(1) {
		lcdWriteCommand(LCD_COMMAND_CLEAR);
		printf("Brak karty");
		//czekaj na woenie karty
		while (PINB & _BV(PINB3));
		//zamontuj system plikw
		FRESULT fresult = f_mount(&fatFs, "", 1);
		if(fresult == FR_OK) {
			FIL fp;
			//otwrz plik.txt do odczytu
			fresult = f_open(&fp, "plik.txt", FA_READ);
			if(fresult == FR_OK) {
				char buff[16];
				//wczytaj linijk
				f_gets(buff, 16, &fp);
				//wywietl linijk
				lcdWriteCommand(LCD_COMMAND_CLEAR);
				printf(buff);
				//zamknij plik
				f_close(&fp);
			} else {
				lcdWriteCommand(LCD_COMMAND_CLEAR);
				printf("Blad pliku");
			}
		} else {
			lcdWriteCommand(LCD_COMMAND_CLEAR);
			printf("Blad karty");
		}
		//czekaj na wycignicie karty
		while (!(PINB & _BV(PINB3)));
	}
}

ISR(TIMER0_COMP_vect)
{
	disk_timerproc();	/* Drive timer procedure of low level disk I/O module */
}
